
Current example for `ConfigOnlyDelegator` is useless with primitive `echo` command.

Propose and pre-configure a better (realistic) command in `argrelay_plugin.yaml` which is:
*   fit the use case of `ConfigOnlyDelegator`
    (not like `git` which actually deserves its own plugin with some logic to execute, not just manual data entry)
*   used by many
    (not some over-specialized command)
*   useful example
    (not simply for the sake of example)

